<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MircastShowWidget</name>
    <message>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <source>Project to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searching for devices...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Invalid folder</source>
        <translation>Ogiltig mapp</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Öppna mapp</translation>
    </message>
    <message>
        <source>Network disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Du har ej behörighet att använda denna mapp</translation>
    </message>
    <message>
        <source>Auto add similar files to play</source>
        <translation>Lägg automatiskt till liknande filer att spela</translation>
    </message>
    <message>
        <source>Clear playlist when exit</source>
        <translation>Rensa spellista vid avslut</translation>
    </message>
    <message>
        <source>Show video preview on mouseover</source>
        <translation>Visa förhandsgranskning vid mouseover</translation>
    </message>
    <message>
        <source>Open a new player for each file played</source>
        <translation>Öppna en ny spelare för varje fil som spelas</translation>
    </message>
    <message>
        <source>Pause when minimized</source>
        <translation>Pausa när minimerad</translation>
    </message>
    <message>
        <source>Remember playback position</source>
        <translation>Kom ihåg uppspelningsposition</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Sökväg</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grundläggande</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skärmdump</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Genvägar</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>Frame/Sound</source>
        <translation>Ram/Ljud</translation>
    </message>
    <message>
        <source>Playback</source>
        <translation>Uppspelning</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Undertext</translation>
    </message>
    <message>
        <source>Font Style</source>
        <translation>Font stil</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Återställ Förval</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Open next</source>
        <translation>Öppna nästa</translation>
    </message>
    <message>
        <source>Open previous</source>
        <translation>Öppna föregående</translation>
    </message>
    <message>
        <source>Mini mode</source>
        <translation>Miniläge</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tysta</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Nästa bildruta</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Föregående bildruta</translation>
    </message>
    <message>
        <source>Volume down</source>
        <translation>Volym ner</translation>
    </message>
    <message>
        <source>Volume up</source>
        <translation>Volym upp</translation>
    </message>
    <message>
        <source>Speed up</source>
        <translation>Öka hastighet</translation>
    </message>
    <message>
        <source>Speed down</source>
        <translation>Säng hastighet</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pausa/Spela</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Spellista</translation>
    </message>
    <message>
        <source>Reset speed</source>
        <translation>Återställ hastighet</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Spola tillbaka</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Framåt</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Ta en skärmbild</translation>
    </message>
    <message>
        <source>0.5s backward</source>
        <translation>0.5s bakåt</translation>
    </message>
    <message>
        <source>0.5s forward</source>
        <translation>0.5s framåt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Exit fullscreen/mini mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visa genvägar</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Film info</translation>
    </message>
    <message>
        <source>Burst shooting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Okej</translation>
    </message>
    <message>
        <source>Show thumbnails in progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default play mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto select (Recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Software decoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Customize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering engine</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Please enter the URL:</source>
        <translation>Var god ange URL:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Okej</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Always on Top</source>
        <translation>Alltid överst</translation>
    </message>
    <message>
        <source>Empty playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film info</source>
        <translation>Film info</translation>
    </message>
    <message>
        <source>Open file</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Öppna mapp</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Öppna länk</translation>
    </message>
    <message>
        <source>Open CD/DVD</source>
        <translation>Öppna CD/DVD</translation>
    </message>
    <message>
        <source>Mini Mode</source>
        <translation>Miniläge</translation>
    </message>
    <message>
        <source>Play Mode</source>
        <translation>Uppspelningsläge</translation>
    </message>
    <message>
        <source>Order Play</source>
        <translation>Spela efter ordning</translation>
    </message>
    <message>
        <source>Shuffle Play</source>
        <translation>Slumpa spelning</translation>
    </message>
    <message>
        <source>Single Play</source>
        <translation>Enskilt spelning</translation>
    </message>
    <message>
        <source>Single Loop</source>
        <translation>Loopa låt</translation>
    </message>
    <message>
        <source>List Loop</source>
        <translation>Loopa spellista</translation>
    </message>
    <message>
        <source>Frame</source>
        <translation>Bildruta</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Förval</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation>Medurs</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation>Moturs</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Vänster kanal</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Höger kanal</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Spår</translation>
    </message>
    <message>
        <source>Subtitle</source>
        <translation>Undertext</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Ladda</translation>
    </message>
    <message>
        <source>Online Search</source>
        <translation>Online Sök</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Välj</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Göm</translation>
    </message>
    <message>
        <source>Encodings</source>
        <translation>Kodningar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Skärmdump</translation>
    </message>
    <message>
        <source>Film Screenshot</source>
        <translation>Ta en skärmbild</translation>
    </message>
    <message>
        <source>Burst Shooting</source>
        <translation>Burst Shooting</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Spellista</translation>
    </message>
    <message>
        <source>Film Info</source>
        <translation>Film Info</translation>
    </message>
    <message>
        <source>Delete from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visa i filhanteraren</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open screenshot folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playback Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.0x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1.5x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2.0x</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <source>Duration: %1</source>
        <translation>Speltid: %1</translation>
    </message>
    <message>
        <source>Resolution: %1</source>
        <translation>Upplösning: %1</translation>
    </message>
    <message>
        <source>Size: %1</source>
        <translation>Storlek: %1</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation>Inläsning lyckades</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation>Inläsning misslyckades</translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation>Buffrar...</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Öppna mapp</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation>Vänster kanal</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation>Höger kanal</translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Tysta</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation>Volym: %1%</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation>Undertext %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation>fördröjd</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation>avancerad</translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation>Hastighet: %1x</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Sparad till</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation>Skärmbilden har sparats</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation>Gick ej att spara skärmbilden</translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation>Ogiltig fil: %1</translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Ogiltig fil</translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation>Ta en skärmbild</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Okej</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Undertext (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <source>%1G</source>
        <translation type="vanished">%1G</translation>
    </message>
    <message>
        <source>%1M</source>
        <translation type="vanished">%1M</translation>
    </message>
    <message>
        <source>%1K</source>
        <translation type="vanished">%1K</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="vanished">%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <source>Film info</source>
        <translation>Film info</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Upplösning</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varaktighet</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Sökväg</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished">%1</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 bps</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <source>Internal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <source>Load successfully</source>
        <translation type="unfinished">Inläsning lyckades</translation>
    </message>
    <message>
        <source>Load failed</source>
        <translation type="unfinished">Inläsning misslyckades</translation>
    </message>
    <message>
        <source>Cannot play the disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parse failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="unfinished">Öppna mapp</translation>
    </message>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed: %1x</source>
        <translation type="unfinished">Hastighet: %1x</translation>
    </message>
    <message>
        <source>Stereo</source>
        <translation type="unfinished">Stereo</translation>
    </message>
    <message>
        <source>Left channel</source>
        <translation type="unfinished">Vänster kanal</translation>
    </message>
    <message>
        <source>Right channel</source>
        <translation type="unfinished">Höger kanal</translation>
    </message>
    <message>
        <source>Track: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to adjust the subtitle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subtitle %1: %2s</source>
        <translation type="unfinished">Undertext %1: %2s</translation>
    </message>
    <message>
        <source>delayed</source>
        <translation type="unfinished">fördröjd</translation>
    </message>
    <message>
        <source>advanced</source>
        <translation type="unfinished">avancerad</translation>
    </message>
    <message>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation type="unfinished">Undertext (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished">Visa</translation>
    </message>
    <message>
        <source>Film screenshot</source>
        <translation type="unfinished">Ta en skärmbild</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished">Sparad till</translation>
    </message>
    <message>
        <source>The screenshot is saved</source>
        <translation type="unfinished">Skärmbilden har sparats</translation>
    </message>
    <message>
        <source>Failed to save the screenshot</source>
        <translation type="unfinished">Gick ej att spara skärmbilden</translation>
    </message>
    <message>
        <source>Taking the screenshots, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading DVD files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No matching online subtitles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4K video may be stuck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">Okej</translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Buffering...</source>
        <translation type="unfinished">Buffrar...</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation type="unfinished">Tysta</translation>
    </message>
    <message>
        <source>Volume: %1%</source>
        <translation type="unfinished">Volym: %1%</translation>
    </message>
    <message>
        <source>Cannot open file or stream</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation type="unfinished">Ogiltig fil</translation>
    </message>
    <message>
        <source>Please insert a CD/DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No video file found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please load the video first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please exit smart dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The CD/DVD has been ejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The action is not supported in this video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid file: %1</source>
        <translation type="unfinished">Ogiltig fil: %1</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miracast disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Spellista</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation type="unfinished">Tom</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <source>Play/Pause</source>
        <translation type="unfinished">Spela/Pausa</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Föregående</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Nästa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Fullskärm</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation type="unfinished">Spellista</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished">Stäng fullskärm</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished">Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Spela</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <source>The file does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <source>Playlist</source>
        <translation>Spellista</translation>
    </message>
    <message>
        <source>%1 videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tom</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <source>%1/Movie%2(%3).jpg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shuffle play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>List loop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Föregående</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Spellista</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Spela/Pausa</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Stäng fullskärm</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Miracast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
